import _JSXStyle from "styled-jsx/style";
import React from "react";
import { Button, Ref } from "semantic-ui-react";
import { CancelIcon } from "@orbit-ui/icons";
import { InputCalendarIcon } from "./assets";
import { KEYS, isNullOrEmpty, useHandlerProxy } from "@orbit-ui/react-components-shared";
import { PureComponent, createRef } from "react";
import { bool, func, node, string } from "prop-types";
import { isNil } from "lodash";
import cx from "classnames";
export class DatePickerTextboxInput extends PureComponent {
  constructor(...args) {
    super(...args);
    this._clearButtonRef = createRef();

    this.setContainerRef = ref => {
      const {
        onBoundingClientRectChange
      } = this.props;

      if (!isNil(ref)) {
        if (!isNil(onBoundingClientRectChange)) {
          setTimeout(() => {
            if (!isNil(ref)) {
              onBoundingClientRectChange(ref.getBoundingClientRect(), this.props);
            }
          }, 0);
        }
      }
    };

    this.handleClick = event => {
      const {
        onClick,
        onOpen,
        allowClear,
        disabled
      } = this.props;
      let canPropagate = true;

      if (allowClear) {
        canPropagate = !this._clearButtonRef.current.contains(event.target);
      }

      if (canPropagate) {
        if (!isNil(onClick)) {
          onClick(event, this.props);
        }

        if (!disabled) {
          onOpen(event, this.props);
        }
      }
    };

    this.handleKeyDown = event => {
      const {
        onKeyDown,
        onOpen,
        disabled
      } = this.props;

      if (!disabled) {
        const key = event.keyCode;

        if (key === KEYS.space || key === KEYS.enter) {
          if (key === KEYS.space) {
            event.preventDefault();
          }

          onOpen(event, this.props);
        }
      }

      if (!isNil(onKeyDown)) {
        onKeyDown(event, this.props);
      }
    };

    this.handleFocus = useHandlerProxy(this, "onFocus");
    this.handleBlur = useHandlerProxy(this, "onBlur");
    this.handleClear = useHandlerProxy(this, "onClear");
  }

  isPlaceholder() {
    const {
      value
    } = this.props;
    return isNullOrEmpty(value);
  }

  getCssClasses() {
    const {
      disabled,
      open,
      className
    } = this.props;
    const openedClasses = open && !disabled ? " b--marine-600 marine-600" : " b--cloud-200 marine-200";
    const disabledClasses = cx({
      " bg-cloud-100 cloud-400 crsr-not-allowed": disabled
    });
    const placeholderClasses = cx({
      " marine-700": !this.isPlaceholder() && !disabled
    });
    const defaultClasses = "input pv3 ph4 ba outline-0 pointer hover-b--marine-600 hover-marine-600 f6 h9 br2 flex items-center".concat(openedClasses).concat(placeholderClasses).concat(disabledClasses);
    return isNil(className) ? defaultClasses : "".concat(defaultClasses, " ").concat(className);
  }

  renderIcon() {
    const {
      icon,
      disabledIcon,
      disabled
    } = this.props;
    return disabled ? disabledIcon : icon;
  }

  renderClearButton() {
    const {
      allowClear,
      clearIcon,
      disabled,
      open
    } = this.props;

    if (!allowClear) {
      return null;
    }

    return React.createElement("div", {
      className: cx({
        dn: this.isPlaceholder() || disabled || open
      })
    }, React.createElement(Ref, {
      innerRef: this._clearButtonRef
    }, React.createElement(Button, {
      circular: true,
      size: "mini",
      primary: true,
      icon: true,
      className: "transparent",
      onClick: this.handleClear,
      "data-testid": "date-picker-textbox-clear-button"
    }, clearIcon)));
  }

  render() {
    const {
      value,
      placeholder,
      disabled
    } = this.props;
    return React.createElement("div", {
      onClick: this.handleClick,
      onKeyDown: this.handleKeyDown,
      onFocus: this.handleFocus,
      onBlur: this.handlerBlur,
      tabIndex: disabled ? null : "0",
      autoComplete: "off",
      disabled: disabled,
      ref: this.setContainerRef,
      "data-testid": "date-picker-textbox-input",
      className: "jsx-2462695752" + " " + (this.getCssClasses() || "")
    }, this.renderIcon(), React.createElement("span", {
      "data-testid": "date-picker-textbox-input-value",
      className: "jsx-2462695752" + " " + "flex-grow-1 ml4"
    }, this.isPlaceholder() ? placeholder : value), this.renderClearButton(), React.createElement(_JSXStyle, {
      id: "2462695752"
    }, [".input.jsx-2462695752:not(\"disabled\"){cursor:text;}", ".input.jsx-2462695752:focus{border:1px solid var(--marine-700);color:var(--marine-700);}"]));
  }

}
DatePickerTextboxInput.propTypes = {
  value: string.isRequired,
  onClick: func,
  onKeyDown: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onFocus: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onBlur: func,
  onOpen: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onClear: func,
  onBoundingClientRectChange: func,
  allowClear: bool,
  placeholder: string,
  icon: node,
  clearIcon: node,
  disabledIcon: node,
  disabled: bool,
  open: bool,
  className: string
};
DatePickerTextboxInput.defaultProps = {
  icon: React.createElement(InputCalendarIcon, {
    className: "w6 h6 fill-marine-700"
  }),
  clearIcon: React.createElement(CancelIcon, {
    className: "h3 w3"
  }),
  disabledIcon: React.createElement(InputCalendarIcon, {
    className: "w6 h6 fill-cloud-500"
  }),
  placeholder: "Pick a date"
};