import React from "react";
import { ChevronIcon } from "@orbit-ui/icons";
import { KEYS, useHandlerProxy } from "@orbit-ui/react-components-shared";
import { PureComponent } from "react";
import { bool, func, node, string } from "prop-types";
import { isNil } from "lodash";
import { momentObj as momentType } from "react-moment-proptypes";
export class InlineSingleDatePickerInput extends PureComponent {
  constructor(...args) {
    super(...args);

    this.setButtonRef = ref => {
      const {
        onBoundingClientRectChange
      } = this.props;

      if (!isNil(ref)) {
        if (!isNil(onBoundingClientRectChange)) {
          setTimeout(() => {
            onBoundingClientRectChange(ref.getBoundingClientRect(), this.props);
          }, 0);
        }
      }
    };

    this.handleClick = event => {
      const {
        onClick,
        onOpen,
        disabled
      } = this.props;

      if (!isNil(onClick)) {
        onClick(event, this.props);
      }

      if (!disabled) {
        onOpen(event, this.props);
      }
    };

    this.handleKeyDown = event => {
      const {
        onKeyDown,
        onOpen,
        disabled
      } = this.props;

      if (!isNil(onKeyDown)) {
        onKeyDown(event, this.props);
      }

      const key = event.keyCode;

      if (key === KEYS.space || key === KEYS.enter) {
        if (key === KEYS.space) {
          event.preventDefault();
        }

        if (!disabled) {
          onOpen(event, this.props);
        }
      }
    };

    this.handleFocus = useHandlerProxy(this, "onFocus");
    this.handleBlur = useHandlerProxy(this, "onBlur");
  }

  componentDidMount() {
    document.addEventListener("keydown", this.handleDocumentKeyDown);
  }

  componentWillUnmount() {
    document.removeEventListener("keydown", this.handleDocumentKeyDown);
  }

  getValue() {
    const {
      date,
      placeholder,
      dateFormat
    } = this.props;

    if (!isNil(date)) {
      return date.format(dateFormat);
    }

    return placeholder;
  }

  getCssClasses() {
    const {
      disabled,
      open,
      className
    } = this.props;
    const openedClasses = open && !disabled ? " bb bw1 b--primary-500" : " bw0 b--transparent";
    const disabledClasses = disabled ? " cloud-200 hover-b--transparent crsr-not-allowed" : " primary-500 bb bw1 b--transparent hover-b--primary-500";
    const defaultClasses = "flex items-center outline-0".concat(openedClasses).concat(disabledClasses);
    return isNil(className) ? defaultClasses : "".concat(defaultClasses, " ").concat(className);
  }

  renderIcon() {
    const {
      openIcon,
      closeIcon,
      disabledOpenIcon,
      disabledCloseIcon,
      open,
      disabled
    } = this.props;

    if (open) {
      return disabled ? disabledOpenIcon : openIcon;
    }

    return disabled ? disabledCloseIcon : closeIcon;
  }

  render() {
    const {
      disabled
    } = this.props;
    return React.createElement("div", {
      onClick: this.handleClick,
      onKeyDown: this.handleKeyDown,
      onFocus: this.handleFocus,
      onBlur: this.handleBlur,
      className: this.getCssClasses(),
      tabIndex: disabled ? null : "0",
      disabled: disabled,
      ref: this.setButtonRef,
      "data-testid": "inline-single-date-picker-input"
    }, React.createElement("span", {
      className: "mr2 fw5"
    }, this.getValue()), React.createElement("span", {
      className: "flex"
    }, this.renderIcon()));
  }

}
InlineSingleDatePickerInput.propTypes = {
  date: momentType,
  onClick: func,
  onKeyDown: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onFocus: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onBlur: func,
  onOpen: func,
  onBoundingClientRectChange: func,
  placeholder: string,
  dateFormat: string,
  openIcon: node,
  closeIcon: node,
  disabledOpenIcon: node,
  disabledCloseIcon: node,
  disabled: bool,
  open: bool,
  className: string
};
InlineSingleDatePickerInput.defaultProps = {
  openIcon: React.createElement(ChevronIcon, {
    className: "w4 h4 rotate-270 fill-primary-500"
  }),
  closeIcon: React.createElement(ChevronIcon, {
    className: "w4 h4 rotate-90 fill-primary-500"
  }),
  disabledOpenIcon: React.createElement(ChevronIcon, {
    className: "w4 h4 rotate-270 fill-cloud-200"
  }),
  disabledCloseIcon: React.createElement(ChevronIcon, {
    className: "w4 h4 rotate-90 fill-cloud-200"
  })
};