import React from "react";
import { DatePickerTextboxInput } from "../date-picker-textbox-input";
import { PureComponent } from "react";
import { bool, func, node, string } from "prop-types";
import { isNil } from "lodash";
import { momentObj as momentType } from "react-moment-proptypes";
import { useHandlerProxy } from "@orbit-ui/react-components-shared";
export class SingleDatePickerInput extends PureComponent {
  constructor(...args) {
    super(...args);
    this.handleBoundingClientRectChange = useHandlerProxy(this, "onBoundingClientRectChange");
    this.handleClick = useHandlerProxy(this, "onClick");
    this.handleKeyDown = useHandlerProxy(this, "onKeyDown");
    this.handleFocus = useHandlerProxy(this, "onFocus");
    this.handleBlur = useHandlerProxy(this, "onBlur");
    this.handleOpen = useHandlerProxy(this, "onOpen");
    this.handleClose = useHandlerProxy(this, "onClose");
  }

  getValue() {
    const {
      date,
      dateFormat
    } = this.props;

    if (!isNil(date)) {
      return date.format(dateFormat);
    }

    return "";
  }

  render() {
    const {
      onClear,
      allowClear,
      placeholder,
      icon,
      clearIcon,
      disabledIcon,
      disabled,
      open,
      className
    } = this.props;
    return React.createElement(DatePickerTextboxInput, {
      value: this.getValue(),
      onClick: this.handleClick,
      onKeyDown: this.handleKeyDown,
      onFocus: this.handleFocus,
      onBlur: this.handleBlur,
      onOpen: this.handleOpen,
      onClose: this.handleClose,
      onClear: onClear,
      onBoundingClientRectChange: this.handleBoundingClientRectChange,
      allowClear: allowClear,
      placeholder: placeholder,
      icon: icon,
      clearIcon: clearIcon,
      disabledIcon: disabledIcon,
      disabled: disabled,
      open: open,
      className: className
    });
  }

}
SingleDatePickerInput.propTypes = {
  date: momentType,
  // eslint-disable-next-line react/no-unused-prop-types
  onClick: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onKeyDown: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onFocus: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onBlur: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onOpen: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onClose: func,
  onClear: func,
  // eslint-disable-next-line react/no-unused-prop-types
  onBoundingClientRectChange: func,
  allowClear: bool,
  placeholder: string,
  dateFormat: string,
  icon: node,
  clearIcon: node,
  disabledIcon: node,
  disabled: bool,
  open: bool,
  className: string
};